@@ -39,3 +39,6 @@
 #define CL_DEFAULT_CHECKS 12
 #define CL_DEFAULT_MAXATTEMPTS 3
 #define CL_MAX_CHILDREN 5
+#define CL_DEFAULT_CONNECTTIMEOUT 30
+#define CL_DEFAULT_RECVTIMEOUT 30
+
