@@ -51,7 +51,7 @@
 #include "../libclamav/str.h" /* cli_strtok */
 #include "dns.h"
 #include "execute.h"
-
+#include "nonblock.h"
 
 int downloadmanager(const struct cfgstruct *copt, const struct optstruct *opt, const char *hostname)
 {
@@ -267,8 +267,20 @@ int downloaddb(const char *localname, const char *remotename, const char *hostna
 	char  *tempname, ipaddr[16], *pt;
 	const char *proxy = NULL, *user = NULL, *pass = NULL;
 	int flevel = cl_retflevel();
+	int ctimeout; /* connect timeout in seconds */
+	int rtimeout; /* recv timeout in seconds */
 
 
+    if((cpt = cfgopt(copt, "ConnectTimeout")))
+	ctimeout = cpt->numarg;
+    else
+	ctimeout = CL_DEFAULT_CONNECTTIMEOUT;
+
+    if((cpt = cfgopt(copt, "ReceiveTimeout")))
+	rtimeout = cpt->numarg;
+    else
+	rtimeout = CL_DEFAULT_RECVTIMEOUT;
+
     if((current = cl_cvdhead(localname)) == NULL)
 	nodb = 1;
 
@@ -327,10 +339,11 @@ int downloaddb(const char *localname, const char *remotename, const char *hostna
     memset(ipaddr, 0, sizeof(ipaddr));
 
     if(!nodb && dbver == -1) {
+
 	if(ip[0]) /* use ip to connect */
-	    hostfd = wwwconnect(ip, proxy, port, ipaddr, localip);
+	    hostfd = wwwconnect(ip, proxy, port, ipaddr, localip, ctimeout);
 	else
-	    hostfd = wwwconnect(hostname, proxy, port, ipaddr, localip);
+	    hostfd = wwwconnect(hostname, proxy, port, ipaddr, localip, ctimeout);
 
 	if(hostfd < 0) {
             mprintf("@No servers could be reached. Giving up\n");
@@ -345,7 +358,7 @@ int downloaddb(const char *localname, const char *remotename, const char *hostna
 	if(!ip[0])
 	    strcpy(ip, ipaddr);
 
-	remote = remote_cvdhead(remotename, hostfd, hostname, proxy, user, pass, &ims);
+	remote = remote_cvdhead(remotename, hostfd, hostname, proxy, user, pass, &ims, rtimeout);
 
 	if(!nodb && !ims) {
 	    mprintf("%s is up to date (version: %d, sigs: %d, f-level: %d, builder: %s)\n", localname, current->version, current->sigs, current->fl, current->builder);
@@ -393,9 +406,9 @@ int downloaddb(const char *localname, const char *remotename, const char *hostna
 
     if(ipaddr[0]) {
 	/* use ipaddr in order to connect to the same mirror */
-	hostfd = wwwconnect(ipaddr, proxy, port, NULL, localip);
+	hostfd = wwwconnect(ipaddr, proxy, port, NULL, localip, ctimeout);
     } else {
-	hostfd = wwwconnect(hostname, proxy, port, ipaddr, localip);
+	hostfd = wwwconnect(hostname, proxy, port, ipaddr, localip, ctimeout);
 	if(!ip[0])
 	    strcpy(ip, ipaddr);
     }
@@ -414,7 +427,7 @@ int downloaddb(const char *localname, const char *remotename, const char *hostna
     tempname = cli_gentemp(".");
 
     mprintf("*Retrieving http://%s/%s\n", hostname, remotename);
-    if((ret = get_database(remotename, hostfd, tempname, hostname, proxy, user, pass))) {
+    if((ret = get_database(remotename, hostfd, tempname, hostname, proxy, user, pass, rtimeout))) {
         mprintf("@Can't download %s from %s (IP: %s)\n", remotename, hostname, ipaddr);
         unlink(tempname);
         free(tempname);
@@ -483,7 +496,7 @@ int downloaddb(const char *localname, const char *remotename, const char *hostna
 
 /* this function returns socket descriptor */
 /* proxy support finshed by njh@bandsman.co.uk */
-int wwwconnect(const char *server, const char *proxy, int pport, char *ip, char *localip)
+int wwwconnect(const char *server, const char *proxy, int pport, char *ip, char *localip, int ctimeout)
 {
 	int socketfd = -1, port, i;
 	struct sockaddr_in name;
@@ -615,7 +628,7 @@ int wwwconnect(const char *server, const char *proxy, int pport, char *ip, char
 	name.sin_addr = *((struct in_addr *) host->h_addr_list[i]);
 	name.sin_port = htons(port);
 
-	if(connect(socketfd, (struct sockaddr *) &name, sizeof(struct sockaddr_in)) == -1) {
+	if(wait_connect(socketfd, (struct sockaddr *) &name, sizeof(struct sockaddr_in), ctimeout) == -1) {
 	    mprintf("Can't connect to port %d of host %s (IP: %s)\n", port, hostpt, ipaddr);
 	    continue;
 	} else {
@@ -635,7 +648,7 @@ int Rfc2822DateTime(char *buf, time_t mtime)
     return strftime(buf, 36, "%a, %d %b %Y %X GMT", time);
 }
 
-struct cl_cvd *remote_cvdhead(const char *file, int socketfd, const char *hostname, const char *proxy, const char *user, const char *pass, int *ims)
+struct cl_cvd *remote_cvdhead(const char *file, int socketfd, const char *hostname, const char *proxy, const char *user, const char *pass, int *ims, int rtimeout)
 {
 	char cmd[512], head[513], buffer[FILEBUFF], *ch, *tmp;
 	int i, j, bread, cnt;
@@ -698,7 +711,7 @@ struct cl_cvd *remote_cvdhead(const char *file, int socketfd, const char *hostna
 
     tmp = buffer;
     cnt = FILEBUFF;
-    while ((bread = recv(socketfd, tmp, cnt, 0)) > 0) {
+    while ((bread = wait_recv(socketfd, tmp, cnt, 0, rtimeout)) > 0) {
 	tmp+=bread;
 	cnt-=bread;
 	if (cnt <= 0) break;
@@ -759,7 +772,7 @@ struct cl_cvd *remote_cvdhead(const char *file, int socketfd, const char *hostna
     return cvd;
 }
 
-int get_database(const char *dbfile, int socketfd, const char *file, const char *hostname, const char *proxy, const char *user, const char *pass)
+int get_database(const char *dbfile, int socketfd, const char *file, const char *hostname, const char *proxy, const char *user, const char *pass, int rtimeout)
 {
 	char cmd[512], buffer[FILEBUFF], *ch;
 	int bread, fd, i, rot = 0;
@@ -829,7 +842,7 @@ int get_database(const char *dbfile, int socketfd, const char *file, const char
     while (1) {
       /* recv one byte at a time, until we reach \r\n\r\n */
 
-      if((i >= sizeof(buffer) - 1) || recv(socketfd, buffer + i, 1, 0) == -1) {
+      if((i >= sizeof(buffer) - 1) || wait_recv(socketfd, buffer + i, 1, 0, rtimeout) == -1) {
         mprintf("@Error while reading database from %s\n", hostname);
         close(fd);
         unlink(file);
@@ -857,7 +870,7 @@ int get_database(const char *dbfile, int socketfd, const char *file, const char
 
     /* receive body and write it to disk */
 
-    while((bread = read(socketfd, buffer, FILEBUFF)) > 0) {
+    while((bread = wait_recv(socketfd, buffer, FILEBUFF, 0, rtimeout)) > 0) {
 	write(fd, buffer, bread);
 	mprintf("Downloading %s [%c]\r", dbfile, rotation[rot]);
 	fflush(stdout);
