@@ -22,7 +22,7 @@
 #include "cltypes.h"
 #include "rebuildpe.h"
 
-int unfsg_200(char *, char *, int, int);
+int unfsg_200(char *, char *, int, int, uint32_t, uint32_t, uint32_t, int);
 int unfsg_133(char *, char *, int , int, struct SECTION *, int, uint32_t, uint32_t, int);
 
 #endif
