@@ -230,7 +230,7 @@ inline static int cli_findpos(const char *buffer, int offset, int length, const
 {
 	int bufferpos = offset + AC_MIN_LENGTH;
 	int postfixend = offset + length;
-	unsigned int i, j, alt = 0, found = 0;
+	unsigned int i, j, alt = 0, found;
 
 
     if(bufferpos >= length)
@@ -242,6 +242,7 @@ inline static int cli_findpos(const char *buffer, int offset, int length, const
 	    return 0;
 
 	if(pattern->pattern[i] == CLI_ALT) {
+	    found = 0;
 	    for(j = 0; j < pattern->altn[alt]; j++) {
 		if(pattern->altc[alt][j] == buffer[bufferpos])
 		    found = 1;
