@@ -27,4 +27,12 @@
  * First draft
  *
  */
-int cli_untar(const char *dir, int desc, unsigned int posix);
+
+#ifndef __UNTAR_H
+#define __UNTAR_H
+
+#include "clamav.h"
+
+int cli_untar(const char *dir, int desc, unsigned int posix, const struct cl_limits *limits);
+
+#endif
