@@ -35,13 +35,13 @@
 typedef struct mac_token_tag
 {
     unsigned char token;
-    unsigned char *str;
+    char *str;
 } mac_token_t;
 
 typedef struct mac_token2_tag
 {
     uint16_t token;
-    unsigned char *str;
+    char *str;
 
 } mac_token2_t;
 
@@ -800,7 +800,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x65:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    print_hex_buff (line_start, buff + i + 2 + s_length, hex_output);
 	    printf ("\n%s", tmp_buff);
@@ -811,7 +811,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x69:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf (" %s", tmp_buff);
 	    free (tmp_buff);
@@ -820,7 +820,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x6a:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf (" \"%s\"", tmp_buff);
 	    free (tmp_buff);
@@ -829,7 +829,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x6b:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf (" '%s", tmp_buff);
 	    free (tmp_buff);
@@ -838,7 +838,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x6d:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf (" %s", tmp_buff);
 	    free (tmp_buff);
@@ -847,7 +847,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x70:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf ("REM%s", tmp_buff);
 	    free (tmp_buff);
@@ -856,7 +856,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x76:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf (" .%s", tmp_buff);
 	    free (tmp_buff);
@@ -865,7 +865,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	case 0x77:
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc (s_length + 1);
-	    strncpy (tmp_buff, buff + i + 2, s_length);
+	    strncpy ((char *) tmp_buff, (char *) (buff + i + 2), s_length);
 	    tmp_buff[s_length] = '\0';
 	    printf ("%s", tmp_buff);
 	    free (tmp_buff);
@@ -875,7 +875,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	    w_length = (uint16_t) (buff[i + 2] << 8) + buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc ((w_length * 2) + 1);
 	    memcpy (tmp_buff, buff + i + 3, w_length * 2);
-	    tmp_name = get_unicode_name (tmp_buff, w_length * 2);
+	    tmp_name = (unsigned char *) get_unicode_name ((char *) tmp_buff, w_length * 2);
 	    free (tmp_buff);
 	    printf ("\"%s\"", tmp_name);
 	    free (tmp_name);
@@ -886,7 +886,7 @@ void wm_decode_macro (unsigned char *buff, uint32_t len, int hex_output)
 	    s_length = (uint8_t) buff[i + 1];
 	    tmp_buff = (unsigned char *) malloc ((s_length * 2) + 1);
 	    memcpy (tmp_buff, buff + i + 2, s_length * 2);
-	    tmp_name = get_unicode_name (tmp_buff, s_length * 2);
+	    tmp_name = (unsigned char *) get_unicode_name ((char *) tmp_buff, s_length * 2);
 	    free (tmp_buff);
 	    printf ("'%s", tmp_name);
 	    free (tmp_name);
@@ -1059,7 +1059,7 @@ int sigtool_vba_scandir (const char *dirname, int hex_output)
 	    if (!data) {
 		cli_dbgmsg ("WARNING: VBA project '%s' decompressed to NULL\n", vba_project->name[i]);
 	    } else {
-		data = (char *) realloc (data, data_len + 1);
+		data = (unsigned char *) realloc (data, data_len + 1);
 		data[data_len] = '\0';
 		printf ("%s", data);
 		free (data);
